==> xkaapi-2.1.tar.gz: xkaapi-2.1/src/machine/cuda/kaapi_cuda_execframe.h <==
/*
** kaapi_cuda_execframe.h
** xkaapi
** 
**
** Copyright 2010 INRIA.
**
** Contributors :
**
** thierry.gautier@inrialpes.fr
** fabien.lementec@imag.fr
** 
** This software is a computer program whose purpose is to execute
** multithreaded computation with data flow synchronization between
** threads.
** 
** This software is governed by the CeCILL-C license under French law
** and abiding by the rules of distribution of free software.  You can
** use, modify and/ or redistribute the software under the terms of
** the CeCILL-C license as circulated by CEA, CNRS and INRIA at the
** following URL "http://www.cecill.info".
** 
** As a counterpart to the access to the source code and rights to
** copy, modify and redistribute granted by the license, users are
** provided only with a limited warranty and the software's author,
** the holder of the economic rights, and the successive licensors
** have only limited liability.
** 
** In this respect, the user's attention is drawn to the risks
** associated with loading, using, modifying and/or developing or
** reproducing the software by the user in light of its specific
** status of free software, that may mean that it is complicated to
** manipulate, and that also therefore means that it is reserved for
** developers and experienced professionals having in-depth computer
** knowledge. Users are therefore encouraged to load and test the
** software's suitability as regards their requirements in conditions
** enabling the security of their systems and/or data to be ensured
** and, more generally, to use and operate it in the same conditions
** as regards security.
** 
** The fact that you are presently reading this means that you have
** had knowledge of the CeCILL-C license and that you accept its
** terms.
** 
*/
#ifndef KAAPI_CUDA_EXECFRAME_H_INCLUDED
#define KAAPI_CUDA_EXECFRAME_H_INCLUDED


struct kaapi_thread_context_t;
struct kaapi_format_t;

int kaapi_cuda_execframe(struct kaapi_thread_context_t *);

int kaapi_cuda_exectask
    (struct kaapi_thread_context_t *, void *, struct kaapi_format_t *);

#if 0
static inline int kaapi_cuda_thread_execframe
    (struct kaapi_thread_context_t *thread) {
  return kaapi_cuda_execframe(thread);
}
#endif

int kaapi_cuda_thread_stack_execframe(kaapi_stack_t * stack);

int kaapi_cuda_thread_execframe_tasklist(struct kaapi_thread_context_t *);


#endif				/* ! KAAPI_CUDA_EXECFRAME_H_INCLUDED */

==> xkaapi-2.2.tar.gz: xkaapi-2.2/src/machine/cuda/kaapi_cuda_execframe.h <==
/*
** kaapi_cuda_execframe.h
** xkaapi
** 
**
** Copyright 2010 INRIA.
**
** Contributors :
**
** thierry.gautier@inrialpes.fr
** fabien.lementec@imag.fr
** 
** This software is a computer program whose purpose is to execute
** multithreaded computation with data flow synchronization between
** threads.
** 
** This software is governed by the CeCILL-C license under French law
** and abiding by the rules of distribution of free software.  You can
** use, modify and/ or redistribute the software under the terms of
** the CeCILL-C license as circulated by CEA, CNRS and INRIA at the
** following URL "http://www.cecill.info".
** 
** As a counterpart to the access to the source code and rights to
** copy, modify and redistribute granted by the license, users are
** provided only with a limited warranty and the software's author,
** the holder of the economic rights, and the successive licensors
** have only limited liability.
** 
** In this respect, the user's attention is drawn to the risks
** associated with loading, using, modifying and/or developing or
** reproducing the software by the user in light of its specific
** status of free software, that may mean that it is complicated to
** manipulate, and that also therefore means that it is reserved for
** developers and experienced professionals having in-depth computer
** knowledge. Users are therefore encouraged to load and test the
** software's suitability as regards their requirements in conditions
** enabling the security of their systems and/or data to be ensured
** and, more generally, to use and operate it in the same conditions
** as regards security.
** 
** The fact that you are presently reading this means that you have
** had knowledge of the CeCILL-C license and that you accept its
** terms.
** 
*/
#ifndef KAAPI_CUDA_EXECFRAME_H_INCLUDED
#define KAAPI_CUDA_EXECFRAME_H_INCLUDED


struct kaapi_thread_context_t;
struct kaapi_format_t;

int kaapi_cuda_exectask(struct kaapi_thread_context_t *, void *, struct kaapi_format_t *);

#if 0
static inline int kaapi_cuda_thread_execframe
    (struct kaapi_thread_context_t *thread) {
  return kaapi_cuda_execframe(thread);
}
#endif

int kaapi_cuda_thread_stack_execframe(kaapi_stack_t * stack);

int kaapi_cuda_thread_execframe_tasklist(struct kaapi_thread_context_t *);


#endif				/* ! KAAPI_CUDA_EXECFRAME_H_INCLUDED */
